/// <reference types="knockout" />
import { Style } from "../style/style";
import { Attribute } from "./attribute";
import { IEventListener } from "./eventListener";
import * as types from "../types/types";
export interface UiElementOptions {
    id?: string;
    elementType?: string;
    visible?: boolean | KnockoutObservable<boolean>;
    className?: string | KnockoutObservable<string>;
    attributes?: Array<Attribute>;
    eventListeners?: Array<IEventListener>;
    style?: Style;
    selectable?: boolean;
    addControlToDataDictionary?: boolean;
}
export declare class UiElement {
    constructor(tagName: string, elementType: string, options?: UiElementOptions);
    private display;
    private setVisibility;
    protected build(): void;
    render(): HTMLElement;
    remove(): void;
    getAttribute(attributeName: string): string;
    setAttribute(name: types.AttributeName, value: string | KnockoutObservable<string>): void;
    deleteAttribute(attributeName: string): void;
    getStyle(cssProperties: Array<types.CssProperty>): Style;
    setStyle(newStyle: Style, overwriteExisting?: boolean): void;
    deleteStyle(style: types.CssProperty | Array<types.CssProperty> | Style): void;
    addEventListener<TType extends keyof HTMLElementEventMap>(type: TType, listener: (this: HTMLElement, event: HTMLElementEventMap[TType], uiElement: UiElement) => any, options?: boolean | AddEventListenerOptions): void;
    element: HTMLElement;
    readonly tagName: string;
    readonly visible: KnockoutObservable<boolean>;
    readonly attributes: {
        [index: string]: string | KnockoutObservable<string>;
    };
    readonly options: UiElementOptions;
}
